-- oldhud
-- replace hud with a pre 1.6 lookalike

local flipself = (gkini.ReadInt("*oldhud", "flip", 0) == 1)

local function oldhudify()
	local gnc = iup.GetNextChild
	local gb = iup.GetBrother
	local gp = iup.GetParent

	local function replacor(frame, gen)
		local child = gnc(frame)
		iup.Detach(child)
		iup.Destroy(frame)
		return gen{child}
	end

	local function scale(size, x, y)
		local ysize = size:gsub(".*x", "")
		local xsize = size:gsub("x.*", "")
		return xsize * x .."x"..ysize * y
	end

	-- selfinfo
	local sparent = gp(HUD.selfinfoframe)
	local spparent = gp(sparent)

	local framegen = flipself and iup.hudleftframe_old or iup.hudrightframe_old

	iup.Detach(HUD.selfinfoframe)
	HUD.selfinfoframe = replacor(HUD.selfinfoframe, framegen)
	HUD.selfinfoframe.EXPAND="HORIZONTAL"

	iup.Detach(HUD.groupinfoframe)
	HUD.groupinfoframe = replacor(HUD.groupinfoframe, framegen)
	HUD.groupinfoframe.EXPAND="HORIZONTAL"


	local neighbors = {}
	
	while true do
		local brother = iup.GetBrother(sparent)
		if not brother then
			break
		end
		table.insert(neighbors, brother)
		iup.Detach(brother)
	end
	
	iup.Destroy(sparent)
	iup.Append(spparent, iup.zbox{HUD.selfinfoframe, HUD.groupinfoframe, expand="NO"})

	for _,ctl in ipairs(neighbors) do
		iup.Append(spparent, ctl)
	end
	
	


	-- license and timer
	-- game crashes if only the frames are replaced
	-- so replace the zbox that houses them aswell
	local lparent = gp(HUD.licensewatchframe)

	iup.Detach(HUD.licensewatchframe)
	HUD.licensewatchframe = replacor(HUD.licensewatchframe, iup.hudrightframe_old)
	HUD.licensewatchframe.size = HUDSize(.25)
	HUD.licensewatchframe.expand = "NO"

	iup.Detach(HUD.missiontimerframe)
	HUD.missiontimerframe = replacor(HUD.missiontimerframe, iup.hudrightframe_old)
	HUD.missiontimerframe.size = HUDSize(.25)
	HUD.missiontimerframe.expand = "NO"

	-- targetinfo
	local tparent = gp(lparent)

	iup.Destroy(lparent)

	iup.Detach(HUD.targetframe)
	HUD.targetframe = replacor(HUD.targetframe, iup.hudrightframe_old)
	HUD.targetframe.size = HUDSize(.25)
	HUD.targetframe.expand = "NO"

	iup.Append(tparent, HUD.targetframe)
	iup.Append(tparent, iup.zbox{HUD.licensewatchframe, HUD.missiontimerframe})


	-- chat
	local chatframe = gnc(HUD.chatframe)
	iup.Detach(chatframe)
	chatframe = replacor(chatframe, iup.hudchatframe_old)
	chatframe.expand = "YES"

	local chattop = iup.frame{iup.label{bgcolor="255 255 255 0 &", title="", image=IMAGE_DIR.."hud_tabbox_ur.png", expand="HORIZONTAL", size="x6"},
		SEGMENTED = "0 1 1 0",
		BORDER = "32 0 24 0", expand="YES", bgcolor="0 0 0 0"
	}

	iup.Append(HUD.chatframe, iup.zbox{chattop, chatframe, all="YES"})


	-- cargo and addons
	iup.Detach(HUD.addoncolumn1)
	iup.Detach(HUD.addoncolumn2)
	iup.Destroy(HUD.alladdonlist)
	HUD.alladdonlist = iup.vbox{HUD.addoncolumn1, HUD.addoncolumn2}

	iup.Detach(HUD.cargocolumn1)
	iup.Detach(HUD.cargocolumn2)
	HUD.firstcargolist = iup.vbox{HUD.cargocolumn1, HUD.cargocolumn2}
	iup.Detach(HUD.morecargoindicator)

	iup.Destroy(gp(HUD.cargoframe)) 
	HUD.cargoframe = HUD.firstcargolist

	local paddons = gp(HUD.addonframe)
	local bsvbox = gb(HUD.voteindicator)

	iup.Destroy(HUD.addonframe)

	iup.Detach(HUD.missionupdateindicator)
	iup.Detach(HUD.voteindicator)
	iup.Detach(bsvbox)

	iup.Detach(HUD.restcargoframe)

	local restcargo = gnc(HUD.restcargoframe)
	iup.Detach(restcargo)
	iup.Destroy(HUD.restcargoframe)
	HUD.restcargoframe = restcargo

	local invbox = iup.hbox{HUD.alladdonlist, HUD.firstcargolist, gap=1}

	if HUD.invclosed then
		HUD.restcargoframe.visible = "NO"
	else
		iup.Append(invbox, HUD.restcargoframe)
	end

	local ChangeAddonElement_old = HUD.ChangeAddonElement
	function HUD:ChangeAddonElement(close)
		if close then
			iup.Detach(HUD.restcargoframe)
		else
			iup.Append(invbox, HUD.restcargoframe)
		end
		iup.Refresh(invbox)
		return ChangeAddonElement_old(self, close)
	end

	HUD.addonframe = iup.hudleftframe_old{invbox, expand = "NO"}

	iup.Append(paddons, HUD.addonframe)
	iup.Append(paddons, HUD.missionupdateindicator)
	iup.Append(paddons, HUD.voteindicator)
	iup.Append(paddons, bsvbox)

	-- powerbars
	local function powerbarwidgets(bar)
		return bar[2], bar[3]
	end
	local speedbar, speedbartext = powerbarwidgets(HUD.speedbar)
	
	speedbar.lowertexture = IMAGE_DIR.."hud_powerbars.png"
	speedbar.lowercolor = "0 255 150 150 +"
	speedbar.uv = "1 0 0 1"

	speedbar.UPPERTEXTURE = IMAGE_DIR.."hud_powerbars.png"
	speedbar.UPPERCOLOR = "0 255 150 90 +"

	speedbar.middleabovetexture = IMAGE_DIR.."hud_powerbars.png"
	speedbar.middleabovecolor = "96 25 21 150 +"

	speedbar.middlebelowtexture = IMAGE_DIR.."hud_powerbars.png"
	speedbar.middlebelowcolor = "255 255 255 150 +"

	speedbar.size = scale(speedbar.size, 1.35, 1)

	speedbartext.size = scale(speedbartext.size, 1.1, 1)
	

	local energybar, energybartext = powerbarwidgets(HUD.energybar)

	energybar.lowertexture = IMAGE_DIR.."hud_powerbars.png"
	energybar.lowercolor = "0 255 150 150 +"
	energybar.uv = "0 0 1 1"

	energybar.UPPERTEXTURE = IMAGE_DIR.."hud_powerbars.png"
	energybar.UPPERCOLOR = "0 255 150 90 +"

	energybar.middleabovetexture = IMAGE_DIR.."hud_powerbars.png"
	energybar.middlebelowtexture = IMAGE_DIR.."hud_powerbars.png"

	energybar.size = scale(energybar.size, 1.35, 1)

	energybartext.size = scale(energybartext.size, 1.1, 1)


	-- distancebar and sectorinfo
	local distancebar = HUD.jumpindicator.distancebar

	local barsize = scale(distancebar.size, 1.5, .7)

	local d3000mparent = gp(HUD.jumpindicator.distance3000m)
	iup.Destroy(d3000mparent)

	distancebar = iup.progressbar{
		expand="YES", 
		LOWERCOLOR="14 153 202 100 +", 
		MIDDLEABOVECOLOR="14 153 202 200 +", 
		UPPERCOLOR = "14 153 202 100 +",
		mode="TRINARY",
		type="HORIZONTAL", 
		MINVALUE=0, 
		MAXVALUE=6000}

	-- without the extra vbox the sizing of the progressbar gets all wonky
	local dbarframe = iup.frame{iup.vbox{distancebar}, bgcolor="0 0 0 0", border="6 6 6 6", segmented=".5 .5 .5 .5", size=barsize, expand="NO"}

	local distance3000m = iup.frame{
		iup.label{image="", title="", expand="YES", bgcolor="14 153 202 200 +"},
		image=IMAGE_DIR.."hud_distance_3000m.png",
		bgcolor = "14 153 202 200 +",
		size=barsize,
		segmented=".5 .5 .5 .5",
		border="6 6 6 6",
		expand="NO"}

	HUD.jumpindicator.distancebar = distancebar
	HUD.jumpindicator.distance_all = dbarframe
	HUD.jumpindicator.distance3000m = distance3000m

	local dnfz = gnc(HUD.distancebar) iup.Detach(dnfz) --
	local dfill1 = gnc(HUD.distancebar) iup.Destroy(dfill1) --
	local dtext = gnc(HUD.distancebar) iup.Detach(dtext) --
	-- already destroyed as d3000mparent
	-- local djump = gnc(HUD.distancebar) iup.Detach(djump)
	local dfill2 = gnc(HUD.distancebar) iup.Destroy(dfill2) --
	local dltext = gnc(HUD.distancebar) iup.Detach(dltext) --
	local dfill3 = gnc(HUD.distancebar) iup.Destroy(dfill3) --
	local dsectalign = gnc(HUD.distancebar) iup.Detach(dsectalign) --


	HUD.distancebar.gap = 0
	dltext.expand = "NO"
	dltext.size = nil
	dsectalign.expand = "NO"
	dsectalign.size = nil

	iup.Append(HUD.distancebar, dnfz)
	iup.Append(HUD.distancebar, iup.hbox{
			   dltext, 
			   iup.label{title=" (", fgcolor="14 153 202"}, 
			   dsectalign, 
			   iup.label{title=")", fgcolor="14 153 202"}})

	iup.Append(HUD.distancebar, iup.zbox{dbarframe, distance3000m, all="YES"})
	iup.Append(HUD.distancebar, dtext)


	HUD.radarlayer[2][1][2].IMAGE = IMAGE_DIR.."hud_radar_left.png"
	HUD.radarlayer[2][1][2].BGCOLOR = "255 255 255 255 &"

	HUD.radarlayer[2][3][2].IMAGE = IMAGE_DIR.."hud_radar_right.png"
	HUD.radarlayer[2][3][2].BGCOLOR = "255 255 255 255 &"

	-- from movesectorinfo
	local sectorinfobox = gp(HUD.distancebar)
	local fill_above = gnc(sectorinfobox)
	local fill_below = gb(gb(gb(fill_above)))
	
	fill_above.size = nil
	-- offset from bottom
	fill_below.size = "5x"
	
	iup.Refresh(HUD.selfinfo)
end

local function modify()
	local reload_old = HUD.Reload
	function HUD:Reload()
		reload_old(self)
		modify()
	end

	oldhudify()
end

modify()


function oldhud_flip_cb()
	flipself = not flipself
	gkini.WriteInt("*oldhud", "flip", flipself and 1 or 0)
	ProcessEvent("rHUDxscale")
end
RegisterUserCommand("oldhud_flip", oldhud_flip_cb)
